@@ -340,7 +340,7 @@ class web:
                 body=web.__tpl(
                     title = status,
                     e=status,
-                    data="无法找到目录："+str(modular)+"/"
+                    data="路由不存在："+str(modular)+"/"
                 )
             else:
                 try:
@@ -350,7 +350,7 @@ class web:
                     body=web.__tpl(
                         title = status,
                         e=status,
-                        data="无法找到目录："+str(modular)+"/controller/"
+                        data="路由不存在："+str(modular)+"/controller/"
                     )
                 else:
                     try:
