@@ -408,12 +408,14 @@ class create:
             http.set_header['username']=username
             http.set_header['timestamp']=str(timestamp)
             http.set_header['sign']=sign
+            http.set_timeout=300
             http.openurl(config.domain['kcwebapi']+"/user/uploadplug/",'POST',
             data={'name':str(plug),'describes':'','modular':self.modular},
             files={'file':open(self.appname+"/"+self.modular+"/controller/"+plug+".zip", 'rb')})
             arr=json_decode(http.get_text)
             if not arr:
                 os.remove(self.appname+"/"+self.modular+"/controller/"+plug+".zip")
+                print(http.get_text)
                 return False,"上传失败，服务器暂时无法处理上传"
             if (arr['code']==-1 or arr['code']==2) and cli:
                 if i >= 3:
@@ -436,13 +438,13 @@ class create:
             else:
                 os.remove(self.appname+"/"+self.modular+"/controller/"+plug+".zip")
                 return False,arr['msg']
-    def installplug(self,plug,edition='',token='',cli=False):
+    def installplug(self,plug,edition='',token='',cli=False,mandatory=False):
         """创建一个插件，如果您的模块目录下没有插件包，则创建默认插件文件
         
         plug 插件名
         """
         plug=str(plug)
-        if os.path.exists(self.appname+"/"+self.modular+"/controller/"+plug):
+        if os.path.exists(self.appname+"/"+self.modular+"/controller/"+plug) and not mandatory:
             return False,"该插件已存在"
         else:
             http=Http()
@@ -513,8 +515,15 @@ class create:
                             #     if not a[0]:
                             #         shutil.rmtree(self.appname+"."+self.modular+"/controller/"+plug)
                             #         return False,str(a[1])
-                            f=open(self.appname+"/"+self.modular+"/controller/__init__.py","a",encoding='utf-8')
-                            text="\nfrom . import "+plug
+
+                            f=open(self.appname+"/"+self.modular+"/controller/__init__.py","r",encoding='utf-8')
+                            text=f.read()
+                            f.close()
+                            text=re.sub("\nfrom . import "+plug,"",text)
+                            text=re.sub("from . import "+plug,"",text)
+
+                            f=open(self.appname+"/"+self.modular+"/controller/__init__.py","w",encoding='utf-8')
+                            text+="\nfrom . import "+plug
                             f.write(text)
                             f.close()
                             return True,"插件安装成功，"+plug+"=="+str(arr['edition'])
@@ -553,12 +562,14 @@ class create:
             http.set_header['username']=username
             http.set_header['timestamp']=str(timestamp)
             http.set_header['sign']=sign
+            http.set_timeout=300
             http.openurl(config.domain['kcwebapi']+"/user/uploadmodular/",'POST',
             data={'name':str(self.modular),'describes':''},
             files={'file':open(self.appname+"/"+self.modular+".zip", 'rb')})
             arr=json_decode(http.get_text)
             if not arr:
                 os.remove(self.appname+"/"+self.modular+".zip")
+                print(http.get_text)
                 return False,"上传失败，服务器暂时无法处理上传"
             if (arr['code']==-1 or arr['code']==2) and cli:
                 if i >= 3:
