@@ -26,9 +26,9 @@ class HEADER:
     def Method():
         return kcwglobals.HEADER.Method
     def URL():
-        return kcwglobals.HEADER.URL
+        return kcwglobals.HEADER.URL.lstrip()
     def PATH_INFO():
-        return kcwglobals.HEADER.PATH_INFO
+        return kcwglobals.HEADER.PATH_INFO.lstrip()
     def SERVER_PROTOCOL():
         return kcwglobals.HEADER.SERVER_PROTOCOL
     def HTTP_HOST():
@@ -42,3 +42,6 @@ def get_json():
         return json.loads(kcwglobals.HEADER.BODY_DATA)
     except:
         return None
+def getroutecomponent():
+    "获取路由"
+    return kcwglobals.VAR.component
