@@ -90,7 +90,7 @@ email['recNick']='' #默认收件人昵称
 
 kcweb={}
 kcweb['name']='kcweb'                             #项目的名称
-kcweb['version']='4.10.7'							#项目版本
+kcweb['version']='4.11.4'							#项目版本
 kcweb['description']=''       #项目的简单描述
 kcweb['long_description']=''     #项目详细描述
 kcweb['license']='MIT'                    #开源协议   mit开源
@@ -103,10 +103,10 @@ kcweb['username']=''
 kcweb['password']=''
 
 domain={}
-domain['kcwebfile']="http://file.kwebapp.cn"
-domain['kcwebstatic']="http://static.kwebapp.cn"
-domain['kcwebimg']="http://img.kwebapp.cn"
-domain['kcwebapi']="http://kcweb.kwebapp.cn"
+domain['kcwebfile']="https://file.kwebapp.cn"
+domain['kcwebstatic']="https://static.kwebapp.cn"
+domain['kcwebimg']="https://img.kwebapp.cn"
+domain['kcwebapi']="https://kcweb.kwebapp.cn"
 
 #其他配置
 other={}
