@@ -35,7 +35,7 @@ class Queues():
             t.daemon=True
             t.start()
     def __messagequeue():
-        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("1=1").delete()
+        kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("code","in",2,3).delete()
         while True:
             if not Queues.__globalqueue.empty():
                 value=Queues.__globalqueue.get()
@@ -56,7 +56,7 @@ class Queues():
                         kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("taskid = '"+value['task']['taskid']+"' and code!=4").update({"code":4,"msg":"执行完成"})
             else:
                 time.sleep(1)
-    def insert(target,args=None,title="默认任务",describes="",msg='等待中'): #add_queue
+    def insert(target,args=None,title="默认任务",describes="",msg='等待中',taskid=None): #add_queue
         """添加队列
         
         target 方法名  必须
@@ -71,15 +71,16 @@ class Queues():
         """
         Queues.start()
         ttt=int(time.time())
-        m = hashlib.md5()
-        m.update((str(ttt)+str(random.randint(100000,999999))).encode(encoding='utf-8'))
-        taskid=m.hexdigest()
+        if not taskid:
+            m = hashlib.md5()
+            m.update((str(ttt)+str(random.randint(100000,999999))).encode(encoding='utf-8'))
+            taskid=m.hexdigest()
         task={"taskid":taskid,"title":title,"describes":describes,"code":2,"msg":msg,"error":"","addtime":ttt}
         key={"target":target,"args":args,"task":task}
         kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").insert(task)
         Queues.__globalqueue.put(key)
         return taskid
-    def getall(code=''):
+    def getall(pagenow=1,pagesize=20,where=None):
         """获取全部队列
 
         code 1获取失败的任务   2获取等待中的任务   3获取正在执行中的任务  4获取执行完成的任务
@@ -89,15 +90,14 @@ class Queues():
         if not os.path.isfile(queuesdbpath):
             model_kcweb_tasks=model_kcweb_task()
             model_kcweb_tasks.create_table()
-        where=False
-        if code:
-            where="code="+str(code)
         try:
-            return kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").field("taskid,title,describes,code,msg,error,addtime").where(where).select()
+            lists=kcwsqlite.sqlite().connect(queuesdbpath).where(where).table("model_kcweb_queues").order("id desc").page(pagenow,pagesize).select()
+            count=kcwsqlite.sqlite().connect(queuesdbpath).where(where).table("model_kcweb_queues").count()
+            return lists,count
         except:
             model_kcweb_tasks=model_kcweb_task()
             model_kcweb_tasks.create_table()
-            return []
+            return [],0
     def status(taskid):
         """获取任务状态
         
@@ -111,7 +111,7 @@ class Queues():
         
         return Boolean
         """
-        if kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("code",3).count():
+        if kcwsqlite.sqlite().connect(queuesdbpath).table("model_kcweb_queues").where("code","in",2,3).count():
             return True
         else:
             return False
